google_rpc

package
v0.0.0-...-5c1723a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 3, 2017 License: Apache-2.0 Imports: 8 Imported by: 0

README

Google RPC

This package contains type definitions for general RPC systems. While gRPC is using these defintions, they are not designed specifically to support gRPC.

Documentation

Overview

Package google_rpc is a generated protocol buffer package.

It is generated from these files:

google/rpc/code.proto
google/rpc/error_details.proto
google/rpc/status.proto

It has these top-level messages:

RetryInfo
DebugInfo
QuotaFailure
BadRequest
RequestInfo
ResourceInfo
Help
Status

Index

Constants

This section is empty.

Variables

var (
	ErrInvalidLengthErrorDetails = fmt.Errorf("proto: negative length found during unmarshaling")
	ErrIntOverflowErrorDetails   = fmt.Errorf("proto: integer overflow")
)
var (
	ErrInvalidLengthStatus = fmt.Errorf("proto: negative length found during unmarshaling")
	ErrIntOverflowStatus   = fmt.Errorf("proto: integer overflow")
)
var Code_name = map[int32]string{
	0:  "OK",
	1:  "CANCELLED",
	2:  "UNKNOWN",
	3:  "INVALID_ARGUMENT",
	4:  "DEADLINE_EXCEEDED",
	5:  "NOT_FOUND",
	6:  "ALREADY_EXISTS",
	7:  "PERMISSION_DENIED",
	16: "UNAUTHENTICATED",
	8:  "RESOURCE_EXHAUSTED",
	9:  "FAILED_PRECONDITION",
	10: "ABORTED",
	11: "OUT_OF_RANGE",
	12: "UNIMPLEMENTED",
	13: "INTERNAL",
	14: "UNAVAILABLE",
	15: "DATA_LOSS",
}
var Code_value = map[string]int32{
	"OK":                  0,
	"CANCELLED":           1,
	"UNKNOWN":             2,
	"INVALID_ARGUMENT":    3,
	"DEADLINE_EXCEEDED":   4,
	"NOT_FOUND":           5,
	"ALREADY_EXISTS":      6,
	"PERMISSION_DENIED":   7,
	"UNAUTHENTICATED":     16,
	"RESOURCE_EXHAUSTED":  8,
	"FAILED_PRECONDITION": 9,
	"ABORTED":             10,
	"OUT_OF_RANGE":        11,
	"UNIMPLEMENTED":       12,
	"INTERNAL":            13,
	"UNAVAILABLE":         14,
	"DATA_LOSS":           15,
}

Functions

This section is empty.

Types

type BadRequest

type BadRequest struct {
	// Describes all violations in a client request.
	FieldViolations []*BadRequest_FieldViolation `protobuf:"bytes,1,rep,name=field_violations,json=fieldViolations" json:"field_violations,omitempty"`
}

Describes violations in a client request. This error type focuses on the syntactic aspects of the request.

func (*BadRequest) Descriptor

func (*BadRequest) Descriptor() ([]byte, []int)

func (*BadRequest) Equal

func (this *BadRequest) Equal(that interface{}) bool

func (*BadRequest) GetFieldViolations

func (m *BadRequest) GetFieldViolations() []*BadRequest_FieldViolation

func (*BadRequest) GoString

func (this *BadRequest) GoString() string

func (*BadRequest) Marshal

func (m *BadRequest) Marshal() (dAtA []byte, err error)

func (*BadRequest) MarshalTo

func (m *BadRequest) MarshalTo(dAtA []byte) (int, error)

func (*BadRequest) ProtoMessage

func (*BadRequest) ProtoMessage()

func (*BadRequest) Reset

func (m *BadRequest) Reset()

func (*BadRequest) Size

func (m *BadRequest) Size() (n int)

func (*BadRequest) String

func (this *BadRequest) String() string

func (*BadRequest) Unmarshal

func (m *BadRequest) Unmarshal(dAtA []byte) error

type BadRequest_FieldViolation

type BadRequest_FieldViolation struct {
	// A path leading to a field in the request body. The value will be a
	// sequence of dot-separated identifiers that identify a protocol buffer
	// field. E.g., "violations.field" would identify this field.
	Field string `protobuf:"bytes,1,opt,name=field,proto3" json:"field,omitempty"`
	// A description of why the request element is bad.
	Description string `protobuf:"bytes,2,opt,name=description,proto3" json:"description,omitempty"`
}

A message type used to describe a single bad request field.

func (*BadRequest_FieldViolation) Descriptor

func (*BadRequest_FieldViolation) Descriptor() ([]byte, []int)

func (*BadRequest_FieldViolation) Equal

func (this *BadRequest_FieldViolation) Equal(that interface{}) bool

func (*BadRequest_FieldViolation) GetDescription

func (m *BadRequest_FieldViolation) GetDescription() string

func (*BadRequest_FieldViolation) GetField

func (m *BadRequest_FieldViolation) GetField() string

func (*BadRequest_FieldViolation) GoString

func (this *BadRequest_FieldViolation) GoString() string

func (*BadRequest_FieldViolation) Marshal

func (m *BadRequest_FieldViolation) Marshal() (dAtA []byte, err error)

func (*BadRequest_FieldViolation) MarshalTo

func (m *BadRequest_FieldViolation) MarshalTo(dAtA []byte) (int, error)

func (*BadRequest_FieldViolation) ProtoMessage

func (*BadRequest_FieldViolation) ProtoMessage()

func (*BadRequest_FieldViolation) Reset

func (m *BadRequest_FieldViolation) Reset()

func (*BadRequest_FieldViolation) Size

func (m *BadRequest_FieldViolation) Size() (n int)

func (*BadRequest_FieldViolation) String

func (this *BadRequest_FieldViolation) String() string

func (*BadRequest_FieldViolation) Unmarshal

func (m *BadRequest_FieldViolation) Unmarshal(dAtA []byte) error

type Code

type Code int32

The canonical error codes for Google APIs. Warnings:

  • Do not change any numeric assignments.
  • Changes to this list should be made only if there is a compelling need that can't be satisfied in another way.

Sometimes multiple error codes may apply. Services should return the most specific error code that applies. For example, prefer `OUT_OF_RANGE` over `FAILED_PRECONDITION` if both codes apply. Similarly prefer `NOT_FOUND` or `ALREADY_EXISTS` over `FAILED_PRECONDITION`.

const (
	// Not an error; returned on success
	//
	// HTTP Mapping: 200 OK
	OK Code = 0
	// The operation was cancelled, typically by the caller.
	//
	// HTTP Mapping: 499 Client Closed Request
	CANCELLED Code = 1
	// Unknown error.  For example, this error may be returned when
	// a `Status` value received from another address space belongs to
	// an error space that is not known in this address space.  Also
	// errors raised by APIs that do not return enough error information
	// may be converted to this error.
	//
	// HTTP Mapping: 500 Internal Server Error
	UNKNOWN Code = 2
	// The client specified an invalid argument.  Note that this differs
	// from `FAILED_PRECONDITION`.  `INVALID_ARGUMENT` indicates arguments
	// that are problematic regardless of the state of the system
	// (e.g., a malformed file name).
	//
	// HTTP Mapping: 400 Bad Request
	INVALID_ARGUMENT Code = 3
	// The deadline expired before the operation could complete. For operations
	// that change the state of the system, this error may be returned
	// even if the operation has completed successfully.  For example, a
	// successful response from a server could have been delayed long
	// enough for the deadline to expire.
	//
	// HTTP Mapping: 504 Gateway Timeout
	DEADLINE_EXCEEDED Code = 4
	// Some requested entity (e.g., file or directory) was not found.
	// For privacy reasons, this code *might* be returned when the client
	// does not have the access rights to the entity.
	//
	// HTTP Mapping: 404 Not Found
	NOT_FOUND Code = 5
	// The entity that a client attempted to create (e.g., file or directory)
	// already exists.
	//
	// HTTP Mapping: 409 Conflict
	ALREADY_EXISTS Code = 6
	// The caller does not have permission to execute the specified
	// operation. `PERMISSION_DENIED` must not be used for rejections
	// caused by exhausting some resource (use `RESOURCE_EXHAUSTED`
	// instead for those errors). `PERMISSION_DENIED` must not be
	// used if the caller can not be identified (use `UNAUTHENTICATED`
	// instead for those errors).
	//
	// HTTP Mapping: 403 Forbidden
	PERMISSION_DENIED Code = 7
	// The request does not have valid authentication credentials for the
	// operation.
	//
	// HTTP Mapping: 401 Unauthorized
	UNAUTHENTICATED Code = 16
	// Some resource has been exhausted, perhaps a per-user quota, or
	// perhaps the entire file system is out of space.
	//
	// HTTP Mapping: 429 Too Many Requests
	RESOURCE_EXHAUSTED Code = 8
	// The operation was rejected because the system is not in a state
	// required for the operation's execution.  For example, the directory
	// to be deleted is non-empty, an rmdir operation is applied to
	// a non-directory, etc.
	//
	// Service implementors can use the following guidelines to decide
	// between `FAILED_PRECONDITION`, `ABORTED`, and `UNAVAILABLE`:
	//  (a) Use `UNAVAILABLE` if the client can retry just the failing call.
	//  (b) Use `ABORTED` if the client should retry at a higher level
	//      (e.g., restarting a read-modify-write sequence).
	//  (c) Use `FAILED_PRECONDITION` if the client should not retry until
	//      the system state has been explicitly fixed.  E.g., if an "rmdir"
	//      fails because the directory is non-empty, `FAILED_PRECONDITION`
	//      should be returned since the client should not retry unless
	//      the files are deleted from the directory.
	//  (d) Use `FAILED_PRECONDITION` if the client performs conditional
	//      REST Get/Update/Delete on a resource and the resource on the
	//      server does not match the condition. E.g., conflicting
	//      read-modify-write on the same resource.
	//
	// HTTP Mapping: 400 Bad Request
	//
	// NOTE: HTTP spec says `412 Precondition Failed` should be used only if
	// the request contains Etag-related headers. So if the server does see
	// Etag-related headers in the request, it may choose to return 412
	// instead of 400 for this error code.
	FAILED_PRECONDITION Code = 9
	// The operation was aborted, typically due to a concurrency issue such as
	// a sequencer check failure or transaction abort.
	//
	// See the guidelines above for deciding between `FAILED_PRECONDITION`,
	// `ABORTED`, and `UNAVAILABLE`.
	//
	// HTTP Mapping: 409 Conflict
	ABORTED Code = 10
	// The operation was attempted past the valid range.  E.g., seeking or
	// reading past end-of-file.
	//
	// Unlike `INVALID_ARGUMENT`, this error indicates a problem that may
	// be fixed if the system state changes. For example, a 32-bit file
	// system will generate `INVALID_ARGUMENT` if asked to read at an
	// offset that is not in the range [0,2^32-1], but it will generate
	// `OUT_OF_RANGE` if asked to read from an offset past the current
	// file size.
	//
	// There is a fair bit of overlap between `FAILED_PRECONDITION` and
	// `OUT_OF_RANGE`.  We recommend using `OUT_OF_RANGE` (the more specific
	// error) when it applies so that callers who are iterating through
	// a space can easily look for an `OUT_OF_RANGE` error to detect when
	// they are done.
	//
	// HTTP Mapping: 400 Bad Request
	OUT_OF_RANGE Code = 11
	// The operation is not implemented or is not supported/enabled in this
	// service.
	//
	// HTTP Mapping: 501 Not Implemented
	UNIMPLEMENTED Code = 12
	// Internal errors.  This means that some invariants expected by the
	// underlying system have been broken.  This error code is reserved
	// for serious errors.
	//
	// HTTP Mapping: 500 Internal Server Error
	INTERNAL Code = 13
	// The service is currently unavailable.  This is most likely a
	// transient condition, which can be corrected by retrying with
	// a backoff.
	//
	// See the guidelines above for deciding between `FAILED_PRECONDITION`,
	// `ABORTED`, and `UNAVAILABLE`.
	//
	// HTTP Mapping: 503 Service Unavailable
	UNAVAILABLE Code = 14
	// Unrecoverable data loss or corruption.
	//
	// HTTP Mapping: 500 Internal Server Error
	DATA_LOSS Code = 15
)

func (Code) EnumDescriptor

func (Code) EnumDescriptor() ([]byte, []int)

func (Code) String

func (x Code) String() string

type DebugInfo

type DebugInfo struct {
	// The stack trace entries indicating where the error occurred.
	StackEntries []string `protobuf:"bytes,1,rep,name=stack_entries,json=stackEntries" json:"stack_entries,omitempty"`
	// Additional debugging information provided by the server.
	Detail string `protobuf:"bytes,2,opt,name=detail,proto3" json:"detail,omitempty"`
}

Describes additional debugging info.

func (*DebugInfo) Descriptor

func (*DebugInfo) Descriptor() ([]byte, []int)

func (*DebugInfo) Equal

func (this *DebugInfo) Equal(that interface{}) bool

func (*DebugInfo) GetDetail

func (m *DebugInfo) GetDetail() string

func (*DebugInfo) GetStackEntries

func (m *DebugInfo) GetStackEntries() []string

func (*DebugInfo) GoString

func (this *DebugInfo) GoString() string

func (*DebugInfo) Marshal

func (m *DebugInfo) Marshal() (dAtA []byte, err error)

func (*DebugInfo) MarshalTo

func (m *DebugInfo) MarshalTo(dAtA []byte) (int, error)

func (*DebugInfo) ProtoMessage

func (*DebugInfo) ProtoMessage()

func (*DebugInfo) Reset

func (m *DebugInfo) Reset()

func (*DebugInfo) Size

func (m *DebugInfo) Size() (n int)

func (*DebugInfo) String

func (this *DebugInfo) String() string

func (*DebugInfo) Unmarshal

func (m *DebugInfo) Unmarshal(dAtA []byte) error

type Help

type Help struct {
	// URL(s) pointing to additional information on handling the current error.
	Links []*Help_Link `protobuf:"bytes,1,rep,name=links" json:"links,omitempty"`
}

Provides links to documentation or for performing an out of band action.

For example, if a quota check failed with an error indicating the calling project hasn't enabled the accessed service, this can contain a URL pointing directly to the right place in the developer console to flip the bit.

func (*Help) Descriptor

func (*Help) Descriptor() ([]byte, []int)

func (*Help) Equal

func (this *Help) Equal(that interface{}) bool
func (m *Help) GetLinks() []*Help_Link

func (*Help) GoString

func (this *Help) GoString() string

func (*Help) Marshal

func (m *Help) Marshal() (dAtA []byte, err error)

func (*Help) MarshalTo

func (m *Help) MarshalTo(dAtA []byte) (int, error)

func (*Help) ProtoMessage

func (*Help) ProtoMessage()

func (*Help) Reset

func (m *Help) Reset()

func (*Help) Size

func (m *Help) Size() (n int)

func (*Help) String

func (this *Help) String() string

func (*Help) Unmarshal

func (m *Help) Unmarshal(dAtA []byte) error
type Help_Link struct {
	// Describes what the link offers.
	Description string `protobuf:"bytes,1,opt,name=description,proto3" json:"description,omitempty"`
	// The URL of the link.
	Url string `protobuf:"bytes,2,opt,name=url,proto3" json:"url,omitempty"`
}

Describes a URL link.

func (*Help_Link) Descriptor

func (*Help_Link) Descriptor() ([]byte, []int)

func (*Help_Link) Equal

func (this *Help_Link) Equal(that interface{}) bool

func (*Help_Link) GetDescription

func (m *Help_Link) GetDescription() string

func (*Help_Link) GetUrl

func (m *Help_Link) GetUrl() string

func (*Help_Link) GoString

func (this *Help_Link) GoString() string

func (*Help_Link) Marshal

func (m *Help_Link) Marshal() (dAtA []byte, err error)

func (*Help_Link) MarshalTo

func (m *Help_Link) MarshalTo(dAtA []byte) (int, error)

func (*Help_Link) ProtoMessage

func (*Help_Link) ProtoMessage()

func (*Help_Link) Reset

func (m *Help_Link) Reset()

func (*Help_Link) Size

func (m *Help_Link) Size() (n int)

func (*Help_Link) String

func (this *Help_Link) String() string

func (*Help_Link) Unmarshal

func (m *Help_Link) Unmarshal(dAtA []byte) error

type QuotaFailure

type QuotaFailure struct {
	// Describes all quota violations.
	Violations []*QuotaFailure_Violation `protobuf:"bytes,1,rep,name=violations" json:"violations,omitempty"`
}

Describes how a quota check failed.

For example if a daily limit was exceeded for the calling project, a service could respond with a QuotaFailure detail containing the project id and the description of the quota limit that was exceeded. If the calling project hasn't enabled the service in the developer console, then a service could respond with the project id and set `service_disabled` to true.

Also see RetryDetail and Help types for other details about handling a quota failure.

func (*QuotaFailure) Descriptor

func (*QuotaFailure) Descriptor() ([]byte, []int)

func (*QuotaFailure) Equal

func (this *QuotaFailure) Equal(that interface{}) bool

func (*QuotaFailure) GetViolations

func (m *QuotaFailure) GetViolations() []*QuotaFailure_Violation

func (*QuotaFailure) GoString

func (this *QuotaFailure) GoString() string

func (*QuotaFailure) Marshal

func (m *QuotaFailure) Marshal() (dAtA []byte, err error)

func (*QuotaFailure) MarshalTo

func (m *QuotaFailure) MarshalTo(dAtA []byte) (int, error)

func (*QuotaFailure) ProtoMessage

func (*QuotaFailure) ProtoMessage()

func (*QuotaFailure) Reset

func (m *QuotaFailure) Reset()

func (*QuotaFailure) Size

func (m *QuotaFailure) Size() (n int)

func (*QuotaFailure) String

func (this *QuotaFailure) String() string

func (*QuotaFailure) Unmarshal

func (m *QuotaFailure) Unmarshal(dAtA []byte) error

type QuotaFailure_Violation

type QuotaFailure_Violation struct {
	// The subject on which the quota check failed.
	// For example, "clientip:<ip address of client>" or "project:<Google
	// developer project id>".
	Subject string `protobuf:"bytes,1,opt,name=subject,proto3" json:"subject,omitempty"`
	// A description of how the quota check failed. Clients can use this
	// description to find more about the quota configuration in the service's
	// public documentation, or find the relevant quota limit to adjust through
	// developer console.
	//
	// For example: "Service disabled" or "Daily Limit for read operations
	// exceeded".
	Description string `protobuf:"bytes,2,opt,name=description,proto3" json:"description,omitempty"`
}

A message type used to describe a single quota violation. For example, a daily quota or a custom quota that was exceeded.

func (*QuotaFailure_Violation) Descriptor

func (*QuotaFailure_Violation) Descriptor() ([]byte, []int)

func (*QuotaFailure_Violation) Equal

func (this *QuotaFailure_Violation) Equal(that interface{}) bool

func (*QuotaFailure_Violation) GetDescription

func (m *QuotaFailure_Violation) GetDescription() string

func (*QuotaFailure_Violation) GetSubject

func (m *QuotaFailure_Violation) GetSubject() string

func (*QuotaFailure_Violation) GoString

func (this *QuotaFailure_Violation) GoString() string

func (*QuotaFailure_Violation) Marshal

func (m *QuotaFailure_Violation) Marshal() (dAtA []byte, err error)

func (*QuotaFailure_Violation) MarshalTo

func (m *QuotaFailure_Violation) MarshalTo(dAtA []byte) (int, error)

func (*QuotaFailure_Violation) ProtoMessage

func (*QuotaFailure_Violation) ProtoMessage()

func (*QuotaFailure_Violation) Reset

func (m *QuotaFailure_Violation) Reset()

func (*QuotaFailure_Violation) Size

func (m *QuotaFailure_Violation) Size() (n int)

func (*QuotaFailure_Violation) String

func (this *QuotaFailure_Violation) String() string

func (*QuotaFailure_Violation) Unmarshal

func (m *QuotaFailure_Violation) Unmarshal(dAtA []byte) error

type RequestInfo

type RequestInfo struct {
	// An opaque string that should only be interpreted by the service generating
	// it. For example, it can be used to identify requests in the service's logs.
	RequestId string `protobuf:"bytes,1,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"`
	// Any data that was used to serve this request. For example, an encrypted
	// stack trace that can be sent back to the service provider for debugging.
	ServingData string `protobuf:"bytes,2,opt,name=serving_data,json=servingData,proto3" json:"serving_data,omitempty"`
}

Contains metadata about the request that clients can attach when filing a bug or providing other forms of feedback.

func (*RequestInfo) Descriptor

func (*RequestInfo) Descriptor() ([]byte, []int)

func (*RequestInfo) Equal

func (this *RequestInfo) Equal(that interface{}) bool

func (*RequestInfo) GetRequestId

func (m *RequestInfo) GetRequestId() string

func (*RequestInfo) GetServingData

func (m *RequestInfo) GetServingData() string

func (*RequestInfo) GoString

func (this *RequestInfo) GoString() string

func (*RequestInfo) Marshal

func (m *RequestInfo) Marshal() (dAtA []byte, err error)

func (*RequestInfo) MarshalTo

func (m *RequestInfo) MarshalTo(dAtA []byte) (int, error)

func (*RequestInfo) ProtoMessage

func (*RequestInfo) ProtoMessage()

func (*RequestInfo) Reset

func (m *RequestInfo) Reset()

func (*RequestInfo) Size

func (m *RequestInfo) Size() (n int)

func (*RequestInfo) String

func (this *RequestInfo) String() string

func (*RequestInfo) Unmarshal

func (m *RequestInfo) Unmarshal(dAtA []byte) error

type ResourceInfo

type ResourceInfo struct {
	// A name for the type of resource being accessed, e.g. "sql table",
	// "cloud storage bucket", "file", "Google calendar"; or the type URL
	// of the resource: e.g. "type.googleapis.com/google.pubsub.v1.Topic".
	ResourceType string `protobuf:"bytes,1,opt,name=resource_type,json=resourceType,proto3" json:"resource_type,omitempty"`
	// The name of the resource being accessed.  For example, a shared calendar
	// name: "example.com_4fghdhgsrgh@group.calendar.google.com", if the current
	// error is [google.rpc.Code.PERMISSION_DENIED][google.rpc.Code.PERMISSION_DENIED].
	ResourceName string `protobuf:"bytes,2,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// The owner of the resource (optional).
	// For example, "user:<owner email>" or "project:<Google developer project
	// id>".
	Owner string `protobuf:"bytes,3,opt,name=owner,proto3" json:"owner,omitempty"`
	// Describes what error is encountered when accessing this resource.
	// For example, updating a cloud project may require the `writer` permission
	// on the developer console project.
	Description string `protobuf:"bytes,4,opt,name=description,proto3" json:"description,omitempty"`
}

Describes the resource that is being accessed.

func (*ResourceInfo) Descriptor

func (*ResourceInfo) Descriptor() ([]byte, []int)

func (*ResourceInfo) Equal

func (this *ResourceInfo) Equal(that interface{}) bool

func (*ResourceInfo) GetDescription

func (m *ResourceInfo) GetDescription() string

func (*ResourceInfo) GetOwner

func (m *ResourceInfo) GetOwner() string

func (*ResourceInfo) GetResourceName

func (m *ResourceInfo) GetResourceName() string

func (*ResourceInfo) GetResourceType

func (m *ResourceInfo) GetResourceType() string

func (*ResourceInfo) GoString

func (this *ResourceInfo) GoString() string

func (*ResourceInfo) Marshal

func (m *ResourceInfo) Marshal() (dAtA []byte, err error)

func (*ResourceInfo) MarshalTo

func (m *ResourceInfo) MarshalTo(dAtA []byte) (int, error)

func (*ResourceInfo) ProtoMessage

func (*ResourceInfo) ProtoMessage()

func (*ResourceInfo) Reset

func (m *ResourceInfo) Reset()

func (*ResourceInfo) Size

func (m *ResourceInfo) Size() (n int)

func (*ResourceInfo) String

func (this *ResourceInfo) String() string

func (*ResourceInfo) Unmarshal

func (m *ResourceInfo) Unmarshal(dAtA []byte) error

type RetryInfo

type RetryInfo struct {
	// Clients should wait at least this long between retrying the same request.
	RetryDelay *google_protobuf.Duration `protobuf:"bytes,1,opt,name=retry_delay,json=retryDelay" json:"retry_delay,omitempty"`
}

Describes when the clients can retry a failed request. Clients could ignore the recommendation here or retry when this information is missing from error responses.

It's always recommended that clients should use exponential backoff when retrying.

Clients should wait until `retry_delay` amount of time has passed since receiving the error response before retrying. If retrying requests also fail, clients should use an exponential backoff scheme to gradually increase the delay between retries based on `retry_delay`, until either a maximum number of retires have been reached or a maximum retry delay cap has been reached.

func (*RetryInfo) Descriptor

func (*RetryInfo) Descriptor() ([]byte, []int)

func (*RetryInfo) Equal

func (this *RetryInfo) Equal(that interface{}) bool

func (*RetryInfo) GetRetryDelay

func (m *RetryInfo) GetRetryDelay() *google_protobuf.Duration

func (*RetryInfo) GoString

func (this *RetryInfo) GoString() string

func (*RetryInfo) Marshal

func (m *RetryInfo) Marshal() (dAtA []byte, err error)

func (*RetryInfo) MarshalTo

func (m *RetryInfo) MarshalTo(dAtA []byte) (int, error)

func (*RetryInfo) ProtoMessage

func (*RetryInfo) ProtoMessage()

func (*RetryInfo) Reset

func (m *RetryInfo) Reset()

func (*RetryInfo) Size

func (m *RetryInfo) Size() (n int)

func (*RetryInfo) String

func (this *RetryInfo) String() string

func (*RetryInfo) Unmarshal

func (m *RetryInfo) Unmarshal(dAtA []byte) error

type Status

type Status struct {
	// The status code, which should be an enum value of [google.rpc.Code][google.rpc.Code].
	Code int32 `protobuf:"varint,1,opt,name=code,proto3" json:"code,omitempty"`
	// A developer-facing error message, which should be in English. Any
	// user-facing error message should be localized and sent in the
	// [google.rpc.Status.details][google.rpc.Status.details] field, or localized by the client.
	Message string `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
	// A list of messages that carry the error details.  There will be a
	// common set of message types for APIs to use.
	Details []*google_protobuf1.Any `protobuf:"bytes,3,rep,name=details" json:"details,omitempty"`
}

The `Status` type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by [gRPC](https://github.com/grpc). The error model is designed to be:

- Simple to use and understand for most users - Flexible enough to meet unexpected needs

Overview

The `Status` message contains three pieces of data: error code, error message, and error details. The error code should be an enum value of [google.rpc.Code][google.rpc.Code], but it may accept additional error codes if needed. The error message should be a developer-facing English message that helps developers *understand* and *resolve* the error. If a localized user-facing error message is needed, put the localized message in the error details or localize it in the client. The optional error details may contain arbitrary information about the error. There is a predefined set of error detail types in the package `google.rpc` which can be used for common error conditions.

Language mapping

The `Status` message is the logical representation of the error model, but it is not necessarily the actual wire format. When the `Status` message is exposed in different client libraries and different wire protocols, it can be mapped differently. For example, it will likely be mapped to some exceptions in Java, but more likely mapped to some error codes in C.

Other uses

The error model and the `Status` message can be used in a variety of environments, either with or without APIs, to provide a consistent developer experience across different environments.

Example uses of this error model include:

  • Partial errors. If a service needs to return partial errors to the client, it may embed the `Status` in the normal response to indicate the partial errors.
  • Workflow errors. A typical workflow has multiple steps. Each step may have a `Status` message for error reporting purpose.
  • Batch operations. If a client uses batch request and batch response, the `Status` message should be used directly inside batch response, one for each error sub-response.
  • Asynchronous operations. If an API call embeds asynchronous operation results in its response, the status of those operations should be represented directly using the `Status` message.
  • Logging. If some API errors are stored in logs, the message `Status` could be used directly after any stripping needed for security/privacy reasons.

func (*Status) Descriptor

func (*Status) Descriptor() ([]byte, []int)

func (*Status) Equal

func (this *Status) Equal(that interface{}) bool

func (*Status) GetCode

func (m *Status) GetCode() int32

func (*Status) GetDetails

func (m *Status) GetDetails() []*google_protobuf1.Any

func (*Status) GetMessage

func (m *Status) GetMessage() string

func (*Status) GoString

func (this *Status) GoString() string

func (*Status) Marshal

func (m *Status) Marshal() (dAtA []byte, err error)

func (*Status) MarshalTo

func (m *Status) MarshalTo(dAtA []byte) (int, error)

func (*Status) ProtoMessage

func (*Status) ProtoMessage()

func (*Status) Reset

func (m *Status) Reset()

func (*Status) Size

func (m *Status) Size() (n int)

func (*Status) String

func (this *Status) String() string

func (*Status) Unmarshal

func (m *Status) Unmarshal(dAtA []byte) error

Jump to